# Thunes

[![pypi](https://github.com/iltoningui/thunes-py/actions/workflows/python-publish.yml/badge.svg?branch=publish)](https://github.com/iltoningui/thunes-py/actions/workflows/python-publish.yml)
[![package](https://github.com/iltoningui/thunes-py/actions/workflows/python-package.yml/badge.svg?branch=main)](https://github.com/iltoningui/thunes-py/actions/workflows/python-package.yml)
[![pylint](https://github.com/iltoningui/thunes-py/actions/workflows/pylint.yml/badge.svg?branch=main)](https://github.com/iltoningui/thunes-py/actions/workflows/pylint.yml)

This Library perform operations

## Features

## Docs

## Instalation

## Setup

## Use

### Create Instance

### 